#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This file is part of adp-api-client.
# https://github.com/adplabs/adp-userinfo-python

# Copyright © 2015-2016 ADP, LLC.

# Licensed under the Apache License, Version 2.0 (the “License”);
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

# http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an “AS IS” BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied.  See the License for the specific language
# governing permissions and limitations under the License.


class userInfoURLMap(object):
    """ This class provides the access to the mapping between the high-level
    method calls and the corresponding ADP API calls for the userinfo product """

    urlMap = dict({})

    def __init__(self):
        self.urlMap['getUserInfo'] = '/core/v1/userinfo'

    def getURIfromMap(self, methodname):
            urival = self.urlMap[methodname]
            return urival



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This file is part of adp-api-client.
# https://github.com/adplabs/adp-userinfo-python

# Copyright © 2015-2016 ADP, LLC.

# Licensed under the Apache License, Version 2.0 (the “License”);
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

# http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an “AS IS” BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied.  See the License for the specific language
# governing permissions and limitations under the License.

from preggy import expect
from mock import patch
from adp_connection.lib import *
from adp_userinfo.lib import *
from tests.base import TestCase


class UserInfoTestCase(TestCase):

    def test_userInfo_for_403(self):
        config = dict({})
        config['clientID'] = '88a73992-07f2-4714-ab4b-de782acd9c4d'
        config['clientSecret'] = 'a130adb7-aa51-49ac-9d02-0d4036b63541'
        config['sslCertPath'] = 'tests_certs/cert.pem'
        config['sslKeyPath'] = 'tests_certs/cert.key'
        config['tokenServerURL'] = 'https://iat-api.adp.com/auth/oauth/v2/token'
        config['disconnectURL'] = 'https://iat-accounts.adp.com/auth/oauth/v2/logout'
        config['apiRequestURL'] = 'https://iat-api.adp.com'
        config['grantType'] = 'client_credentials'

        try:
            ClientCredentialsConfiguration = ConnectionConfiguration().init(config)
            ccConnection = ADPAPIConnectionFactory().createConnection(ClientCredentialsConfiguration)
            ccConnection.connect()
            if (ccConnection.isConnectedIndicator()):
                userInfoHelper = UserInfoHelper(ccConnection)
                userinfo = userInfoHelper.getUserInfo()
                print str(userinfo)
        except APICallError as apierr:
            expect(apierr.code).to_equal('403')

    @patch("adp_userinfo.lib.userInfoHelper.requests")
    def test_userInfo_for_success(self, mock_requests):
        # def test_userInfo_for_success(self):
        config = dict({})
        config['clientID'] = '88a73992-07f2-4714-ab4b-de782acd9c4d'
        config['clientSecret'] = 'a130adb7-aa51-49ac-9d02-0d4036b63541'
        config['sslCertPath'] = 'tests_certs/cert.pem'
        config['sslKeyPath'] = 'tests_certs/cert.key'
        config['tokenServerURL'] = 'https://iat-api.adp.com/auth/oauth/v2/token'
        config['disconnectURL'] = 'https://iat-accounts.adp.com/auth/oauth/v2/logout'
        config['apiRequestURL'] = 'https://iat-api.adp.com'
        config['grantType'] = 'client_credentials'

        try:
            ClientCredentialsConfiguration = ConnectionConfiguration().init(config)
            ccConnection = ADPAPIConnectionFactory().createConnection(ClientCredentialsConfiguration)
            ccConnection.connect()
            if (ccConnection.isConnectedIndicator()):
                ccConnection.getConfig().setGrantType('authorization_code')
                userInfoHelper = UserInfoHelper(ccConnection)
                userinfo = userInfoHelper.callAPI('/core/v1/userinfo')
                mock_requests.get.assert_called_with(config['apiRequestURL']+'/core/v1/userinfo',
                                                     cert=('tests_certs/cert.pem', 'tests_certs/cert.key'),
                                                     headers={'Authorization': 'Bearer ' + ccConnection.getAccessToken()})
                expect(userinfo).to_equal(mock_requests.get.return_value)
        except Exception as apierr:
            print 'error is ' + str(apierr)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This file is part of adp-api-client.
# https://github.com/adplabs/adp-userinfo-python

# Copyright © 2015-2016 ADP, LLC.

# Licensed under the Apache License, Version 2.0 (the “License”);
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

# http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an “AS IS” BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied.  See the License for the specific language
# governing permissions and limitations under the License.

from adp_userinfo.version import __version__  # NOQA



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This file is part of adp-api-client.
# https://github.com/adplabs/adp-userinfo-python

# Copyright © 2015-2016 ADP, LLC.

# Licensed under the Apache License, Version 2.0 (the “License”);
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

# http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an “AS IS” BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied.  See the License for the specific language
# governing permissions and limitations under the License.

from adp_connection.lib.adpapiconnection import *
from userinfoexceptions import *
from userinfourlmap import *
from adp_userinfo import __version__


class UserInfoHelper(object):
    """ Helper class for the user_info API Product

    Attributes:
    connObj: instance of ADPAPIConnection - could be either ClientCredentialsConnection
    or AuthorizationCodeConnection """

    def __init__(self, connObj):
        """ Initializes the UserInfoHelper instance with the connection
        and the api url map """
        self.adpapiconnection = connObj
        self.userInfoMap = userInfoURLMap()
        self.userAgent = 'adp-userinfo-python/' + __version__

    def callAPI(self, apiuri):
        """ ADP API requester that makes the actual api calls and returns the
        responses

        Attibutes:
        apiri: the actual API uri to be called
        Returns: response from the api GET request """
        connectionConfiguration = self.adpapiconnection.getConfig()
        headers = {'Authorization': 'Bearer ' + self.adpapiconnection.getAccessToken(), 'user-agent': self.userAgent}
        r = requests.get(connectionConfiguration.getApiRequestURL() + apiuri,
                         cert=(connectionConfiguration.getSSLCertPath(),
                               connectionConfiguration.getSSLKeyPath()),
                         headers=headers)
        logging.debug(r.status_code)
        logging.debug(r.json())
        return r

    def getUserInfo(self):
        """ Helper method to get the user_info by calling the proper
        ADP API.

        Returns: UserInfo JSON object upon a successful response
        An unsuccessful response raises the APICallError containing the
        status code and message returned by the api call """
        apiuri = self.userInfoMap.getURIfromMap('getUserInfo')
        r = self.callAPI(apiuri)
        if r.status_code == requests.codes.ok:
            return r.json()
        else:
            raise APICallError(self.__class__.__name__, str(r.status_code), r.text)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This file is part of adp-api-client.
# https://github.com/adplabs/adp-userinfo-python

# Copyright © 2015-2016 ADP, LLC.

# Licensed under the Apache License, Version 2.0 (the “License”);
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

# http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an “AS IS” BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied.  See the License for the specific language
# governing permissions and limitations under the License.

from setuptools import setup, find_packages
from adp_userinfo import __version__

tests_require = [
    'mock',
    'nose',
    'coverage',
    'yanc',
    'preggy',
    'tox',
    'ipdb',
    'coveralls',
    'sphinx',
]

setup(
    name='adp_userinfo',
    version=__version__,
    description='ADP client library to get the logged-in user''s info',
    long_description='''
ADP client library to get the logged-in user's info
''',
    keywords='ADP userinfo',
    author='Copyright © 2015-2016 ADP, LLC.',
    author_email='Vishal.Shah-Contractor@adp.com',
    url='https://github.com/adplabs/adp-userinfo-python',
    license='Apache Software License',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        'Operating System :: Unix',
        'Programming Language :: Python :: 2.7',
        'Operating System :: OS Independent',
    ],
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        # add your dependencies here
        # remember to use 'package-name>=x.y.z,<x.y+1.0' notation (this way you get bugfixes)
        'adp_connection>=1.0.0'
    ],
    extras_require={
        'tests': tests_require,
    },
    entry_points={
        'console_scripts': [
            # add cli scripts here in this form:
            # 'adp_userinfo=adp_userinfo.cli:main',
        ],
    },
)
